<?php

namespace Laraecart\Filter\Policies;

use Litepie\User\Contracts\UserPolicy;
use Laraecart\Filter\Models\FilterGroup;

class FilterGroupPolicy
{

    /**
     * Determine if the given user can view the filter_group.
     *
     * @param UserPolicy $user
     * @param FilterGroup $filter_group
     *
     * @return bool
     */
    public function view(UserPolicy $user, FilterGroup $filter_group)
    {
        if ($user->canDo('filter.filter_group.view') && $user->isAdmin()) {
            return true;
        }

        return $filter_group->user_id == user_id() && $filter_group->user_type == user_type();
    }

    /**
     * Determine if the given user can create a filter_group.
     *
     * @param UserPolicy $user
     * @param FilterGroup $filter_group
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('filter.filter_group.create');
    }

    /**
     * Determine if the given user can update the given filter_group.
     *
     * @param UserPolicy $user
     * @param FilterGroup $filter_group
     *
     * @return bool
     */
    public function update(UserPolicy $user, FilterGroup $filter_group)
    {
        if ($user->canDo('filter.filter_group.edit') && $user->isAdmin()) {
            return true;
        }

        return $filter_group->user_id == user_id() && $filter_group->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given filter_group.
     *
     * @param UserPolicy $user
     * @param FilterGroup $filter_group
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FilterGroup $filter_group)
    {
        return $filter_group->user_id == user_id() && $filter_group->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given filter_group.
     *
     * @param UserPolicy $user
     * @param FilterGroup $filter_group
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FilterGroup $filter_group)
    {
        if ($user->canDo('filter.filter_group.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given filter_group.
     *
     * @param UserPolicy $user
     * @param FilterGroup $filter_group
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FilterGroup $filter_group)
    {
        if ($user->canDo('filter.filter_group.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
