<?php

namespace Laraecart\Filter\Policies;

use Litepie\User\Contracts\UserPolicy;
use Laraecart\Filter\Models\Filter;

class FilterPolicy
{

    /**
     * Determine if the given user can view the filter.
     *
     * @param UserPolicy $user
     * @param Filter $filter
     *
     * @return bool
     */
    public function view(UserPolicy $user, Filter $filter)
    {
        if ($user->canDo('filter.filter.view') && $user->isAdmin()) {
            return true;
        }

        return $filter->user_id == user_id() && $filter->user_type == user_type();
    }

    /**
     * Determine if the given user can create a filter.
     *
     * @param UserPolicy $user
     * @param Filter $filter
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('filter.filter.create');
    }

    /**
     * Determine if the given user can update the given filter.
     *
     * @param UserPolicy $user
     * @param Filter $filter
     *
     * @return bool
     */
    public function update(UserPolicy $user, Filter $filter)
    {
        if ($user->canDo('filter.filter.edit') && $user->isAdmin()) {
            return true;
        }

        return $filter->user_id == user_id() && $filter->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given filter.
     *
     * @param UserPolicy $user
     * @param Filter $filter
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Filter $filter)
    {
        return $filter->user_id == user_id() && $filter->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given filter.
     *
     * @param UserPolicy $user
     * @param Filter $filter
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Filter $filter)
    {
        if ($user->canDo('filter.filter.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given filter.
     *
     * @param UserPolicy $user
     * @param Filter $filter
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Filter $filter)
    {
        if ($user->canDo('filter.filter.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
